==> python-pygls-0.10.2-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/pygls/lsp/types/client.py <==
############################################################################
# Original work Copyright 2017 Palantir Technologies, Inc.                 #
# Original work licensed under the MIT License.                            #
# See ThirdPartyNotices.txt in the project root for license information.   #
# All modifications Copyright (c) Open Law Library. All rights reserved.   #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License")           #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#     http: // www.apache.org/licenses/LICENSE-2.0                         #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
############################################################################
"""This module contains Language Server Protocol types
https://microsoft.github.io/language-server-protocol/specification

-- Client --

Class attributes are named with camel-case notation because client is expecting
that.
"""
from typing import Any, List, Optional

from pygls.lsp.types.basic_structures import Model


class Registration(Model):
    id: str
    method: str
    register_options: Optional[Any] = None


class RegistrationParams(Model):
    registrations: List[Registration]


class Unregistration(Model):
    id: str
    method: str


class UnregistrationParams(Model):
    unregisterations: List[Unregistration]

==> python-pygls-0.13.0-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/pygls/lsp/types/client.py <==
############################################################################
# Original work Copyright 2017 Palantir Technologies, Inc.                 #
# Original work licensed under the MIT License.                            #
# See ThirdPartyNotices.txt in the project root for license information.   #
# All modifications Copyright (c) Open Law Library. All rights reserved.   #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License")           #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#     http: // www.apache.org/licenses/LICENSE-2.0                         #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
############################################################################
"""This module contains Language Server Protocol types
https://microsoft.github.io/language-server-protocol/specification

-- Client --

Class attributes are named with camel case notation because client is expecting
that.
"""
from typing import Any, List, Optional

from pygls.lsp.types.basic_structures import Model


class Registration(Model):
    id: str
    method: str
    register_options: Optional[Any]


class RegistrationParams(Model):
    registrations: List[Registration]


class Unregistration(Model):
    id: str
    method: str


class UnregistrationParams(Model):
    unregisterations: List[Unregistration]
